@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11802 2019-12-17 16:04:02Z Lavender $
+# $Id: __init__.py 11817 2019-12-24 14:40:36Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-12-18 01:04:02 +0900 (週三, 18 十二月 2019) $
-# $Revision: 11802 $
+# $Date: 2019-12-24 23:40:36 +0900 (週二, 24 十二月 2019) $
+# $Revision: 11817 $
 
 import os
 import sys
@@ -351,6 +351,14 @@ def attachSettings(settingsDict, enablePaypal=False):
     cathaybkEnable = False
     if 'IUNO_SHOP_CATHAYBK_ENABLE' in settingsDict:
         cathaybkEnable = settingsDict['IUNO_SHOP_CATHAYBK_ENABLE']
+        
+    atmEnable = False
+    if hasattr(settings, 'IUNO_SHOP_ATM_ENABLE'):
+        atmEnable = settings.IUNO_SHOP_ATM_ENABLE
+        
+    if atmEnable:
+        require('IUNO_SHOP_ATM_EXPIRED_HOURS', settingsDict)
+        require('IUNO_SHOP_ATM_PAYMENT_INFO', settingsDict)
 
     ADDING_OSCAR_DASHBOARD_NAVIGATION = {
         'label': _('Payment'),
@@ -520,6 +528,7 @@ def attachSettings(settingsDict, enablePaypal=False):
         else:
             ADDING_OSCAR_ORDER_STATUS = {
                 'OSCAR_INITIAL_ORDER_STATUS': u'完成訂單',
+                'OSCAR_ORDER_COMPLETE_STATUS': u'完成訂單',
                 'OSCAR_INITIAL_LINE_STATUS': '-',
                 'OSCAR_ORDER_STATUS_PIPELINE': {
                     u'完成訂單': (u'測試用訂單', ),
@@ -631,6 +640,10 @@ def attachShopURLs(settings, urlpatterns):
     cathaybkEnable = False
     if hasattr(settings, 'IUNO_SHOP_CATHAYBK_ENABLE'):
         cathaybkEnable = settings.IUNO_SHOP_CATHAYBK_ENABLE
+        
+    atmEnable = False
+    if hasattr(settings, 'IUNO_SHOP_ATM_ENABLE'):
+        atmEnable = settings.IUNO_SHOP_ATM_ENABLE
 
     if not VERSION >= (2, 0, 0):
         if paypalEnable:
@@ -647,10 +660,11 @@ def attachShopURLs(settings, urlpatterns):
             url(r'^cathaybk-credit/checkxml/', views.returnCathaybkCreditXml),
         )
 
-    if ecpayEnable or allpayEnable or spgatewayEnable:
+    if (ecpayEnable or allpayEnable or spgatewayEnable or 
+        cathaybkEnable or atmEnable):
         urlpatterns += patterns('',
             url(r'^(?P<name>.*)/preview/', 
-                views.SuccessResponseView2.as_view()),
+                views.SuccessResponseView2.as_view(), name='paymentPreview'),
         )
     if ecpayEnable:
         urlpatterns += patterns('',
@@ -691,6 +705,13 @@ def attachShopURLs(settings, urlpatterns):
                     views.CathaybkCreditTransactionListView.as_view()),
                 name='cathaybkCreditTransaction'),
         )
+        
+    if atmEnable:
+        urlpatterns += patterns('',
+            url(r'^shop/atm/(?P<orderNumber>[\w-]*)/fill/', 
+                views.ATMFillView.as_view(),
+                name='atmFill'),
+        )
 
 # ------------------------------------------------------------------------------
 import hashlib
@@ -721,6 +742,7 @@ ECPAY = 'ecpay'
 ECPAY_MAP = 'ecpay_map'
 ECPAY_LOGISTIC = 'ecpay_logistic'
 CATHAYBK = 'cathaybk'
+ATM = 'atm'
 
 class AllPay2(AllPay):
     def __init__(self, paymentConf, serviceMethod='post'):
@@ -778,6 +800,10 @@ def buildAPIForm(submission, request, apiName, extra={}):
     if hasattr(settings, 'IUNO_SHOP_CATHAYBK_ENABLE'):
         cathaybkEnable = settings.IUNO_SHOP_CATHAYBK_ENABLE
         
+    atmEnable = False
+    if hasattr(settings, 'IUNO_SHOP_ATM_ENABLE'):
+        atmEnable = settings.IUNO_SHOP_ATM_ENABLE
+        
     enable = {
         SPGATEWAY: spgatewayEnable,
         ALLPAY: allpayEnable,
@@ -785,10 +811,11 @@ def buildAPIForm(submission, request, apiName, extra={}):
         CATHAYBK: cathaybkEnable,
         ECPAY_LOGISTIC: ecpayEnable,
         ECPAY_MAP: ecpayEnable,
+        ATM: atmEnable,
     }
 
     if not apiName in [SPGATEWAY, ALLPAY, ECPAY, 
-                       CATHAYBK, ECPAY_LOGISTIC, ECPAY_MAP]:
+                       CATHAYBK, ECPAY_LOGISTIC, ECPAY_MAP, ATM]:
         raise ValueError("Not pay api name: %s" % apiName)
         
     if not enable[apiName]:
@@ -1103,6 +1130,16 @@ def buildAPIForm(submission, request, apiName, extra={}):
         
         return form
         
+    if apiName == ATM:
+        temp = get_template('shop/payment/ATM.html')
+        context = {
+            'data': {
+                'total': int(total),
+                'basketId': request.basket.id,
+            },
+        }
+        form = temp.render(context)
+        
     if not form:
         return None
     else:             
